Summarizing the posterior mean of the log-normal expectation might be delicate since several
common priors used for the variance do not produces posteriors with finite moments. The proposal by Fabrizi and Trivisano (2012) of adopting a generalized inverse Gaussian (GIG)
prior for the variance in the log scale \(\sigma^2\) has been implemented. Moreover, they discussed how to specify the hyperparameters according to two different aims.
Firstly, a weakly informative
prior allowed to produce posterior credible intervals with good frequentist properties, whereas a prior aimed at minimizing the point estimator
MSE was proposed too. The choice between the two priors can be made through the argument method.
The point estimates are exact values, whereas the credible intervals are provided through simulations from the posterior distribution.